/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package javax.context;

import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Dependent scope type.
 * <p>
 * If webbeans or its stereotypes do not define its scope type,
 * default scope type is <code>Dependent</code> scope.
 * </p>
 * 
 * <p>
 * Every webbeans instance has an associated dependent context. Each dependent context
 * is destroyed with its parent webbeans component instance.
 * </p>
 * 
 * <p>
 * Please see <b>8.3 Dependent pseudo-scope</b> of the specification
 * for getting furhter information.
 * </p>
 * 
 */
@ScopeType(normal = false)
@Target( { ElementType.TYPE, ElementType.METHOD, ElementType.FIELD })
@Retention(RetentionPolicy.RUNTIME)
@Inherited
public @interface Dependent
{

}
